==> haskell-bower-json-1.0.0.1-88-x86_64.pkg.tar.xz: usr/share/haskell/register/haskell-bower-json.sh <==
#!/bin/sh
export PATH='/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
echo 'name: bower-json
version: 1.0.0.1
id: bower-json-1.0.0.1-IYL7aKTTvW3scFRhrzXCO
key: bower-json-1.0.0.1-IYL7aKTTvW3scFRhrzXCO
license: MIT
maintainer: harry@garrood.me
author: Harry Garrood
homepage: https://github.com/hdgarrood/bower-json
synopsis: Read bower.json from Haskell
description:
    Bower is a package manager for the web (see <http://bower.io>).
    This package provides a data type and ToJSON/FromJSON instances for Bower'\''s
    package manifest file, bower.json.
category: Web
abi: f205d011e815cbd1f76ab4f1b8f5f2cd
exposed: True
exposed-modules:
    Web.Bower.PackageMeta
hidden-modules: Web.Bower.PackageMeta.Internal
import-dirs: /usr/lib/ghc-8.6.1/site-local/bower-json-1.0.0.1
library-dirs: /usr/lib/ghc-8.6.1/site-local/bower-json-1.0.0.1
dynamic-library-dirs: /usr/lib
data-dir: /usr/share/x86_64-linux-ghc-8.6.1/bower-json-1.0.0.1
hs-libraries: HSbower-json-1.0.0.1-IYL7aKTTvW3scFRhrzXCO
depends:
    aeson-1.4.1.0-GPncuQLCkBq39NZScMfTsF
    aeson-better-errors-0.9.1.0-Dw74S8XpLgB9fYUkcwGFnO base-4.12.0.0
    bytestring-0.10.8.2 deepseq-1.4.4.0 ghc-prim-0.5.3 mtl-2.2.2
    scientific-0.3.6.2-2Qg8WlJf6PLET7HqXRUMwz text-1.2.3.1
    transformers-0.5.5.0
    unordered-containers-0.2.9.0-LB7iMl6A8usDj0EAzhnafU
    vector-0.12.0.1-BKWaeB2IPwRDyZEP11mv5m
haddock-interfaces: /usr/share/doc/haskell-bower-json/html/bower-json.haddock
haddock-html: /usr/share/doc/haskell-bower-json/html
' | '/usr/bin/ghc-pkg' 'update' '--force' '-' '--global' '--no-user-package-db' "$@"

==> haskell-bower-json-1.0.0.1-92-x86_64.pkg.tar.xz: usr/share/haskell/register/haskell-bower-json.sh <==
#!/bin/sh
export PATH='/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
echo 'name: bower-json
version: 1.0.0.1
id: bower-json-1.0.0.1-9zy5wJy9e112gS6mpSaN02
key: bower-json-1.0.0.1-9zy5wJy9e112gS6mpSaN02
license: MIT
maintainer: harry@garrood.me
author: Harry Garrood
homepage: https://github.com/hdgarrood/bower-json
synopsis: Read bower.json from Haskell
description:
    Bower is a package manager for the web (see <http://bower.io>).
    This package provides a data type and ToJSON/FromJSON instances for Bower'\''s
    package manifest file, bower.json.
category: Web
abi: 9596e6b7f1fe66074d6f4bb4fffda30b
exposed: True
exposed-modules:
    Web.Bower.PackageMeta
hidden-modules: Web.Bower.PackageMeta.Internal
import-dirs: /usr/lib/ghc-8.6.3/site-local/bower-json-1.0.0.1
library-dirs: /usr/lib/ghc-8.6.3/site-local/bower-json-1.0.0.1
dynamic-library-dirs: /usr/lib
data-dir: /usr/share/x86_64-linux-ghc-8.6.3/bower-json-1.0.0.1
hs-libraries: HSbower-json-1.0.0.1-9zy5wJy9e112gS6mpSaN02
depends:
    aeson-1.4.2.0-BdBVLho0lrWC4iPoef6lEw
    aeson-better-errors-0.9.1.0-56qP4WZRQhm12uChZeAtI6 base-4.12.0.0
    bytestring-0.10.8.2 deepseq-1.4.4.0 ghc-prim-0.5.3 mtl-2.2.2
    scientific-0.3.6.2-9lkO4JSfZDD3N7SSlCrzCi text-1.2.3.1
    transformers-0.5.5.0
    unordered-containers-0.2.9.0-BISrknrydugK8yp2XIgTJd
    vector-0.12.0.2-5G85DK6NPIx1LphnqJy7eO
haddock-interfaces: /usr/share/doc/haskell-bower-json/html/bower-json.haddock
haddock-html: /usr/share/doc/haskell-bower-json/html
' | '/usr/bin/ghc-pkg' 'update' '--force' '-' '--global' '--no-user-package-db' "$@"
